Runs the solver executable and extracts the quantity of interest (QOI) and its Jacobian matrix (if available).
run(solver, x, ...) # S3 method for solver run(solver, x, ...) # S3 method for r_solver run(solver, x, ...) # S3 method for shell_solver run(solver, x, ignore.stdout = NULL, ignore.stderr = NULL, silent = FALSE, ...)
| solver | solver object. |
|---|---|
| x | numeric, the point (parameter set) at which QOI is evaluated. |
| ... | additional arguments passed to other functions, note that
particular solvers can have some |
| ignore.stdout | logical, if not |
| ignore.stderr | logical, if not |
| silent | logical, suppress diagnostic messages (not warnings), |
List with components:
qoiQOI value at x, default implementation returns NA;
jacobianQOI Jacobian matrix at x, default implementation
returns NA, NA is also returned if the solver does not provide Jacobian
info.
solver: Checks if number of solver parameters (unless
NULL) equals length of given point and delegates to default method.
r_solver: Computes output using provided functions.
shell_solver: Runs solver executable and reads values from output
file(s). If solver process exits with non-zero status code, a warning is
issued and list of NA's is returned.
run(x = 10)#> $qoi #> [1] NA #> #> $jacobian #> [1] NA #>#> $qoi #> [1] NA #> #> $jacobian #> [1] NA #>